pub struct Instant(/* private fields */);Expand description
An instant in time.
This instant can be produced by Clock. Mixing instants from different clocks is not
supported and leads to undefined results but not undefined behaviour.
Implementations
Sourceimpl Instant
impl Instant
Sourcepub fn from_duration(duration: Duration) -> Self
pub fn from_duration(duration: Duration) -> Self
Creates a new Instant from a duration.
The meaning of the duration is up to the caller, usually a specific Clock.
For example a system clock may take offsets from a specific std::time::Instant,
a CPU time measurement may use a duration representing the amount of nano seconds
passed since the start of the task.